@@ -81,6 +81,39 @@ class TwoCaptcha():
         result = self.solve(**method, **kwargs)
         return result
 
+    def audio(self, file, lang, **kwargs):
+        '''
+        Wrapper for solving audio captcha
+        
+        Required:
+            file (base64, or url to mp3 file)
+            lang ("en", "ru", "de", "el", "pt")
+
+        Optional params:
+        '''
+        method = "audio"
+
+        if not file:
+            raise ValidationException('File is none')
+        elif not '.' in file and len(file) > 50:
+            body = file
+        elif file.endswith(".mp3") and file.startswith("http"):
+            response = requests.get(file)
+            if response.status_code != 200:
+                raise ValidationException(f'File could not be downloaded from url: {file}')
+            body = b64encode(response.content).decode('utf-8')
+        elif file.endswith(".mp3"):
+            with open(file, "rb") as media:
+                body = b64encode(media.read()).decode('utf-8')                
+        else:
+            raise ValidationException('File extension is not .mp3 or it is not a base64 string.')
+
+        if not lang or lang not in ("en", "ru", "de", "el", "pt"):
+            raise ValidationException(f'Lang not in "en", "ru", "de", "el", "pt". You send {lang}')
+
+        result = self.solve(body=body, method=method, **kwargs)
+        return result
+
     def text(self, text, **kwargs):
         '''
         Wrapper for solving text captcha 
@@ -470,7 +503,67 @@ class TwoCaptcha():
         
         return result
 
+    def mtcaptcha(self, sitekey, url, **kwargs):
+        '''
+        Wrapper for solving MTCaptcha
 
+        Required:
+            sitekey
+            url
+
+        Optional params:
+            softId
+            callback
+            proxy           =  {'type': 'HTTPS', 'uri': 'login:password@IP_address:PORT'})
+        '''
+
+        result = self.solve(sitekey=sitekey,
+                            url=url,
+                            method='mt_captcha',
+                            **kwargs)
+        return result
+
+    def friendly_captcha(self, sitekey, url, **kwargs):
+        '''
+        Wrapper for solving Friendly Captcha
+
+        Required:
+            sitekey
+            url
+
+        Optional params:
+            softId
+            callback
+            proxy           =  {'type': 'HTTPS', 'uri': 'login:password@IP_address:PORT'})
+        '''
+
+        result = self.solve(sitekey=sitekey,
+                            url=url,
+                            method='friendly_captcha',
+                            **kwargs)
+        return result
+
+    def cutcaptcha(self, misery_key, apikey, url, **kwargs):
+        '''
+        Wrapper for solving Friendly Captcha
+
+        Required:
+            misery_key
+            apikey
+            url
+
+        Optional params:
+            softId
+            callback
+            proxy           =  {'type': 'HTTPS', 'uri': 'login:password@IP_address:PORT'})
+        '''
+
+        result = self.solve(misery_key=misery_key,
+                            api_key=apikey,
+                            url=url,
+                            method='cutcaptcha',
+                            **kwargs)
+        return result
 
     def solve(self, timeout=0, polling_interval=0, **kwargs):
         '''
@@ -524,7 +617,7 @@ class TwoCaptcha():
 
         if not '.' in file and len(file) > 50:
             return {'method': 'base64', 'body': file}
-        
+
         if file.startswith('http'):
             img_resp = requests.get(file)
             if img_resp.status_code != 200:
@@ -601,6 +694,8 @@ class TwoCaptcha():
             'caseSensitive': 'regsense',
             'minLen': 'min_len',
             'maxLen': 'max_len',
+            'minLength': 'min_len',
+            'maxLength': 'max_len',
             'hintText': 'textinstructions',
             'hintImg': 'imginstructions',
             'url': 'pageurl',
